# Code and data management with Git

This is the website for the course *Code and data management with Git*. This
course consists of an introduction to working with the
[Git](http://git-scm.com/) version control system for data analysis and is
aimed primarily at researchers in the LUMC.

The Git system is widely used by software developers, but can also be used for
project management. In the LUMC we use [GitLab](https://git.lumc.nl) as a
collaborative environment on top of Git. By keeping track of all versions,
history, etc, GitLab makes your projects more reproducible and collaboration
with colleagues easy ([introduction](http://doc.gitlab.com/ce/gitlab-basics/README.html)).


## Coordinates

Details for the next session:
- Date: November 22nd, 2017
- Time: 9:30 - 16:30
- Location: J1-84
- Teachers:
  - TBA
- Registration via www.medgencentre.nl. Direct access to the [registration form](https://forms.lumc.nl/lumc2/GITcourse).


## Program

| Time  | Subject                                                                                | Teacher           | Contents                  |
| ----- | -----------------                                                                      | ----------------- | ------------------------- |
| 10:00 | [Introduction](/uploads/c751916e71cc02c026491fad6c171a7d/introduction.pdf)             | Mihai Lefter      | Welcome, version control introduction |
| 10:30 | [Git basics](/uploads/5c35a9ecd72033b42ef55b602f6cb548/20170906_-_git-course_-_git-basics.pdf) | Wibowo Arindrarto | Basic Git command line flow |
| 11:15 | [Practical](/uploads/d56ee5edaeca415c5430b385750a89de/basics_handouts.pdf)             |                   |                           |
| 12:00 | Lunch                                                                                  |                   |                           |
| 13:00 | [Collaboration: remote repositories](/uploads/a189f6a373afac0509d96812d7a2b49a/remotes.pdf)   | Jonathan Vis   | Sharing and collaborating via remotes |
| 13:45 | [Practical](/uploads/286d7abb800c6f3f1540a49a6aefd25b/remotes_handouts.pdf)             |                   |                           |
| 14:15 | Break                                                                                  |                   |                           |
| 14:30 | [Collaboration: combining changes by merging](/uploads/daec1d922f0bfe036adfea260dba26b0/merging.pdf)  | Mihai Lefter   | Commit graph, merging, resolving merge conflicts |
| 15:15 | [Practical](/uploads/d8fb514d9181aed85ff2843ce80ec4d0/merging_handouts.pdf)            |                   |                           |
| 15:45 | Break                                                                                  |                   |                           |
| 16:00 | [Extras](/uploads/6421469e8b44778f7c57958ba5f36171/extras.pdf)  | Mihai Lefter   | GitLab and Markdown. |
| 16:30 | [Practical](/uploads/3cde4b0450bf749bb5b9a7954adb8f33/extras_handouts.pdf)            |                   |                           |
| 17:00 | Questions, closing                                                                     |                   |                           |


## Prerequisites

Affinity with the UNIX shell is required before taking the course. For
example, our
[Practical Linux Course](https://git.lumc.nl/courses/practical-linux-course)
is more than enough. In addition, you can find some nice 
[tutorials here](http://www.ee.surrey.ac.uk/Teaching/Unix/).

We encourage you to bring your own laptop, but make sure it has a terminal and
[Git](http://git-scm.com/) installed. We work with
[Linux](http://en.wikipedia.org/wiki/Linux), but Git also runs on Mac OSX.
Windows is not ideal, but here are [some suggestions](WINDOWS.md).

We can also provide you with a laptop that has all the required software
installed. The lessons are interactive, meaning that you really need a
laptop.


## Further reading

- [Code School - Try Git](https://try.github.io/) (you could even try this
  before the course)
- [The entire Pro Git book](http://git-scm.com/book) on the official [Git
  website](http://git-scm.com/)
- [Ry's Git Tutorial](http://rypress.com/tutorials/git/index.html)
- [Git tutorials at Atlassian](https://www.atlassian.com/git/tutorials)
- [Learn Git Branching](http://pcottle.github.io/learnGitBranching/)
- [Git cheat sheet](https://git.wiki.kernel.org/index.php/GitCheatSheet)
  (useful for printing)


## Past course dates

- September 6th, 2017: Code and data management with Git
- October 14th, 2013: Git introduction course
- June 23rd, 2014: Git introduction course
- December 1st, 2015: Code and data management with Git
- April 25th, 2016: Code and data management with Git

For corresponding snapshots of this repository, see [tags](https://git.lumc.nl/humgen/gitcourse/tags).


## Using the course materials

There is one [Git submodule](https://git-scm.com/book/en/v2/Git-Tools-Submodules)
on which this repository depends:

- **[presentation](https://git.lumc.nl/j.f.j.laros/presentation)** template for
  presentations in LaTeX.

First clone this repository, then fetch the data from the submodule:

    git clone https://git.lumc.nl/humgen/gitcourse.git
    cd gitcourse
    git submodule init
    git submodule update

A new presentation can be added like this:

    cd presentation
    bash mkpres.sh ../mypresentation
